@@ -1,4 +1,3 @@
-
 #' Download Latest isd-history.csv File and Update an Internal Database
 #'
 #' This function downloads the latest station list (isd-history.csv) from the
@@ -22,9 +21,10 @@
 #'
 #' @examples
 #' \dontrun{
-#'  update_station_list()
+#' update_station_list()
 #' }
-#'
+#' @returns Called for side-effects of saving a file to disk, returns an
+#'  invisible `NULL`.
 #' @seealso [get_isd_history()]
 #' @author Adam H. Sparks, \email{adamhsparks@@gmail.com}
 #' @autoglobal
@@ -37,12 +37,12 @@ update_station_list <- function() {
   )
 
   answer <-
-    readLines(con = getOption("GSODR_connection"), n = 1)
+    readLines(con = getOption("GSODR_connection"), n = 1L)
 
   answer <- toupper(answer)
 
   if (answer != "Y" & answer != "YES") {
-    stop("Station list was not updated.")
+    stop("Station list was not updated.", call. = FALSE)
   }
 
   isd_history <- get_isd_history()
@@ -51,4 +51,5 @@ update_station_list <- function() {
   fname <-
     system.file("extdata", "isd_history.rda", package = "GSODR")
   save(isd_history, file = fname, compress = "bzip2")
+  return(invisible(NULL))
 }
